@@ -20,7 +20,6 @@ import enum
 import io
 import json
 import logging
-import re
 import zipfile
 
 import pkg_resources
@@ -595,7 +594,12 @@ class ResourceBase(object, metaclass=abc.ABCMeta):
         for key, registry in registries.items():
             if (registry
                     and self._attribute_registry in (key, registry.identity)):
-                if language != registry.language:
+                # NOTE(iurygregory): some registries may have "en-US"
+                # as their language, in this case we can check if the
+                # registry language starts with the requested language.
+                registry_language = registry.language.lower().split('-', 1)[0]
+                if (language != registry.language
+                        and language.lower() != registry_language):
                     LOG.debug('Found %(descr)s but its language %(reg_lang)s '
                               'does not match the requested %(lang)s',
                               {'descr': description,
@@ -638,21 +642,7 @@ class ResourceBase(object, metaclass=abc.ABCMeta):
 
         :returns ETag or None
         """
-        etag = self._get_headers().get('ETag')
-        if not etag:
-            return None
-
-        # Note (arne_wiebalck): in case there is a weak Etag,
-        # return it with and without the qualifier to handle
-        # vendor implementations which may require one or the
-        # other (but should actually not use weak tags in the
-        # first place).
-        pattern = re.compile(r'^(W\/)("\w*")$')
-        match = pattern.match(etag)
-        if match:
-            return etag + ',' + match.group(2)
-
-        return etag
+        return self._get_headers().get('ETag')
 
     def _get_headers(self):
         """Returns the HTTP headers of the request for the resource.
