@@ -16,8 +16,6 @@ from http import client as http_client
 import json
 from unittest import mock
 
-import requests
-
 import sushy
 from sushy import exceptions
 from sushy.resources.certificateservice import certificate
@@ -175,21 +173,48 @@ class VirtualMediaTestCase(base.TestCase):
             ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1"),
             data={"Image": "https://www.dmtf.org/freeImages/Sardine.img",
                   "Inserted": True, "WriteProtected": False},
-            headers={"If-Match": 'W/"3d7b8a7360bf2941d","3d7b8a7360bf2941d"'})
+            headers={"If-Match": 'W/"3d7b8a7360bf2941d"'})
         self.assertTrue(self.sys_virtual_media._is_stale)
 
-    @mock.patch.object(requests, 'post', autospec=True)
-    def test_is_transfer_protocol_required(self, mock_post):
+    def test_is_transfer_protocol_required(self):
         with open('sushy/tests/unit/json_samples/'
                   'transfer_proto_required_error.json') as f:
             response_obj = json.load(f)
-        response = mock.MagicMock()
-        response.status_code = 400
-        response.code = "Base.1.5.ActionParameterMissing"
-        response.body = response_obj['error']
-        response.raise_for_status.side_effect = requests.exceptions.HTTPError
-        mock_post.return_value = response
-        retval = self.sys_virtual_media.is_transfer_protocol_required(response)
+        response = mock.Mock(spec=['json', 'status_code'])
+        response.json.return_value = response_obj
+        error = exceptions.HTTPError('GET', 'VirtualMedia', response)
+        retval = self.sys_virtual_media.is_transfer_protocol_required(error)
+        self.assertTrue(retval)
+
+    def test_is_transfer_protocol_required_alt(self):
+        with open('sushy/tests/unit/json_samples/'
+                  'transfer_proto_required_error.json') as f:
+            response_obj = json.load(f)
+        response_obj['error']['code'] = 'Base.1.5.PropertyMissing'
+        response = mock.Mock(spec=['json', 'status_code'])
+        response.json.return_value = response_obj
+        error = exceptions.HTTPError('GET', 'VirtualMedia', response)
+        retval = self.sys_virtual_media.is_transfer_protocol_required(error)
+        self.assertTrue(retval)
+
+    def test_is_transfer_protocol_required_alt2(self):
+        with open('sushy/tests/unit/json_samples/'
+                  'transfer_proto_required_error2.json') as f:
+            response_obj = json.load(f)
+        response = mock.Mock(spec=['json', 'status_code'])
+        response.json.return_value = response_obj
+        error = exceptions.HTTPError('GET', 'VirtualMedia', response)
+        retval = self.sys_virtual_media.is_transfer_protocol_required(error)
+        self.assertTrue(retval)
+
+    def test_is_transfer_method_required(self):
+        with open('sushy/tests/unit/json_samples/'
+                  'transfer_method_required_error.json') as f:
+            response_obj = json.load(f)
+        response = mock.Mock(spec=['json', 'status_code'])
+        response.json.return_value = response_obj
+        error = exceptions.HTTPError('POST', 'VirtualMedia', response)
+        retval = self.sys_virtual_media.is_transfer_method_required(error)
         self.assertTrue(retval)
 
     def test_eject_media_none(self):
@@ -239,7 +264,7 @@ class VirtualMediaTestCase(base.TestCase):
         self.sys_virtual_media._conn.patch.assert_called_once_with(
             ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1"),
             data={"Image": None, "Inserted": False},
-            headers={"If-Match": 'W/"3d7b8a7360bf2941d","3d7b8a7360bf2941d"'})
+            headers={"If-Match": 'W/"3d7b8a7360bf2941d"'})
         self.assertTrue(self.sys_virtual_media._is_stale)
 
     def test_eject_media_pass_empty_dict_415(self):
