@@ -56,11 +56,11 @@ class BiosTestCase(base.TestCase):
         with open('sushy/tests/unit/json_samples/'
                   'bios_attribute_registry.json') as f:
             conn.get.return_value.json.return_value = json.load(f)
-            bios_reg = attribute_registry.AttributeRegistry(
+            self.bios_reg = attribute_registry.AttributeRegistry(
                 conn, '/redfish/v1/Registries/BiosRegistryTest',
                 redfish_version='1.0.2')
 
-            registries['BiosRegistry.1.0'] = bios_reg
+            registries['BiosRegistry.1.0'] = self.bios_reg
 
         self.sys_bios = bios.Bios(
             self.conn, '/redfish/v1/Systems/437XR1138R2/BIOS',
@@ -118,23 +118,7 @@ class BiosTestCase(base.TestCase):
                           parser.parse('2020-09-01T04:30:00-06:00')},
                          attributes.get('maintenance_window'))
 
-    def test_set_attribute(self):
-        self.sys_bios.set_attribute('ProcTurboMode', 'Disabled')
-        self.sys_bios._conn.patch.assert_called_once_with(
-            '/redfish/v1/Systems/437XR1138R2/BIOS/Settings',
-            data={'Attributes': {'ProcTurboMode': 'Disabled'}})
-
     def test_set_attribute_apply_time(self):
-        self.sys_bios.set_attribute('ProcTurboMode', 'Disabled',
-                                    res_cons.ApplyTime.ON_RESET)
-        self.sys_bios._conn.patch.assert_called_once_with(
-            '/redfish/v1/Systems/437XR1138R2/BIOS/Settings',
-            data={'Attributes': {'ProcTurboMode': 'Disabled'},
-                  '@Redfish.SettingsApplyTime': {
-                      '@odata.type': '#Settings.v1_0_0.PreferredApplyTime',
-                      'ApplyTime': 'OnReset'}})
-
-    def test_set_attribute_apply_time_with_maintenance_window(self):
         self.sys_bios.set_attribute(
             'ProcTurboMode', 'Disabled',
             res_cons.ApplyTime.IN_MAINTENANCE_WINDOW_ON_RESET,
@@ -166,26 +150,6 @@ class BiosTestCase(base.TestCase):
         self.assertTrue(self.conn.get.called)
 
     def test_set_attributes(self):
-        self.sys_bios.set_attributes({'ProcTurboMode': 'Disabled',
-                                      'UsbControl': 'UsbDisabled'})
-        self.sys_bios._conn.patch.assert_called_once_with(
-            '/redfish/v1/Systems/437XR1138R2/BIOS/Settings',
-            data={'Attributes': {'ProcTurboMode': 'Disabled',
-                                 'UsbControl': 'UsbDisabled'}})
-
-    def test_set_attributes_apply_time(self):
-        self.sys_bios.set_attributes({'ProcTurboMode': 'Disabled',
-                                      'UsbControl': 'UsbDisabled'},
-                                     res_cons.ApplyTime.IMMEDIATE)
-        self.sys_bios._conn.patch.assert_called_once_with(
-            '/redfish/v1/Systems/437XR1138R2/BIOS/Settings',
-            data={'Attributes': {'ProcTurboMode': 'Disabled',
-                                 'UsbControl': 'UsbDisabled'},
-                  '@Redfish.SettingsApplyTime': {
-                      '@odata.type': '#Settings.v1_0_0.PreferredApplyTime',
-                      'ApplyTime': 'Immediate'}})
-
-    def test_set_attributes_apply_time_with_maintenance_window(self):
         self.sys_bios.set_attributes(
             {'ProcTurboMode': 'Disabled', 'UsbControl': 'UsbDisabled'},
             res_cons.ApplyTime.AT_MAINTENANCE_WINDOW_START,
@@ -201,30 +165,6 @@ class BiosTestCase(base.TestCase):
                       'MaintenanceWindowStartTime': '2020-09-01T04:30:00',
                       'MaintenanceWindowDurationInSeconds': 600}})
 
-    def test_set_attributes_apply_time_missing(self):
-        self.assertRaises(ValueError,
-                          self.sys_bios.set_attributes,
-                          {'ProcTurboMode': 'Disabled',
-                           'UsbControl': 'UsbDisabled'},
-                          maint_window_start_time=datetime.datetime.now(),
-                          maint_window_duration=600)
-
-    def test_set_attributes_maint_window_start_time_missing(self):
-        self.assertRaises(ValueError,
-                          self.sys_bios.set_attributes,
-                          {'ProcTurboMode': 'Disabled',
-                           'UsbControl': 'UsbDisabled'},
-                          res_cons.ApplyTime.AT_MAINTENANCE_WINDOW_START,
-                          maint_window_duration=600)
-
-    def test_set_attributes_maint_window_duration_missing(self):
-        self.assertRaises(ValueError,
-                          self.sys_bios.set_attributes,
-                          {'ProcTurboMode': 'Disabled',
-                           'UsbControl': 'UsbDisabled'},
-                          res_cons.ApplyTime.AT_MAINTENANCE_WINDOW_START,
-                          datetime.datetime.now())
-
     def test_set_attributes_on_refresh(self):
         self.conn.get.reset_mock()
         # make it to instantiate pending attributes
@@ -383,6 +323,14 @@ class BiosTestCase(base.TestCase):
                           {'ValueDisplayName': 'Disabled',
                            'ValueName': 'Disabled'}])
 
+    def test_get_attribute_registry_by_key(self):
+        # This is seen on some SuperMicro hardware
+        self.sys_bios._registries[self.bios_reg.identity] = self.bios_reg
+        self.bios_reg.identity = 'I.dont.match'
+        registry = self.sys_bios.get_attribute_registry()
+        self.assertIsNotNone(registry)
+        self.assertEqual(registry.name, 'BIOS Attribute Registry')
+
     def test_get_attribute_registry_no_lang(self):
 
         registry = self.sys_bios.get_attribute_registry(language='zh')
@@ -393,3 +341,89 @@ class BiosTestCase(base.TestCase):
         self.sys_bios._attribute_registry = "Unknown"
         registry = self.sys_bios.get_attribute_registry()
         self.assertIsNone(registry)
+
+
+class BiosZTTestCase(base.TestCase):
+
+    def setUp(self):
+        super(BiosZTTestCase, self).setUp()
+        self.conn = mock.Mock()
+        with open('sushy/tests/unit/json_samples/bios_zt.json') as f:
+            self.bios_json = json.load(f)
+        # NOTE(iurygregory): ZT Hardware doesn't have Settings for Bios.
+
+        self.conn.get.return_value.json.side_effect = [self.bios_json]
+
+        registries = {}
+        conn = mock.Mock()
+        # Note(iurygregory): re-use message registry for now.
+        with open('sushy/tests/unit/json_samples/message_registry.json') as f:
+            conn.get.return_value.json.return_value = json.load(f)
+            msg_reg = message_registry.MessageRegistry(
+                conn, '/redfish/v1/Registries/Test',
+                redfish_version='1.0.2')
+
+            registries['Test.1.0'] = msg_reg
+
+        with open('sushy/tests/unit/json_samples/'
+                  'bios_attribute_registry_zthardware.json') as f:
+            conn.get.return_value.json.return_value = json.load(f)
+            self.bios_reg = attribute_registry.AttributeRegistry(
+                conn,
+                '/redfish/v1/Registries/BiosAttributeRegistryProt0.208.208.0',
+                redfish_version='1.3.1')
+
+            registries['BiosAttributeRegistryProt0.208.208.0'] = self.bios_reg
+
+        self.sys_bios = bios.Bios(
+            self.conn, '/redfish/v1/Systems/Self/Bios',
+            registries=registries,
+            redfish_version='1.0.2')
+
+    def test__parse_attributes(self):
+        self.sys_bios._parse_attributes(self.bios_json)
+        self.assertEqual('1.0.2', self.sys_bios.redfish_version)
+        self.assertEqual('Bios', self.sys_bios.identity)
+        self.assertEqual('Current BIOS Settings',
+                         self.sys_bios.name)
+        self.assertEqual(self.sys_bios.description,
+                         'Current BIOS Settings')
+        self.assertEqual('BiosAttributeRegistryProt0.208.208.0',
+                         self.sys_bios._attribute_registry)
+
+    def test_get_attribute_registry_no_lang(self):
+
+        registry = self.sys_bios.get_attribute_registry(language='zh')
+        self.assertIsNone(registry)
+
+    def test_get_attribute_registry(self):
+
+        registry = self.sys_bios.get_attribute_registry(language="en")
+        registry2 = self.sys_bios.get_attribute_registry(language="en-US")
+
+        self.assertEqual(registry.name, 'Prot0 BIOS Attribute Registry')
+        self.assertEqual(registry.description, 'This registry defines a '
+                         'representation of BIOS Attribute instances')
+        self.assertEqual(registry.language, 'en-US')
+        self.assertEqual(registry.registry_entries.attributes[0].name,
+                         'TCG003')
+        self.assertEqual(registry.registry_entries.attributes[0].display_name,
+                         'TPM SUPPORT')
+        self.assertEqual(registry.registry_entries.attributes[0].read_only,
+                         False)
+        self.assertEqual(registry.registry_entries.attributes[0].
+                         attribute_type, 'Enumeration')
+
+        self.assertEqual(registry.name, registry2.name)
+        self.assertEqual(registry.description, registry2.description)
+        self.assertEqual(registry.language, registry2.language)
+        self.assertEqual(registry.registry_entries.attributes[0].name,
+                         registry2.registry_entries.attributes[0].name)
+        self.assertEqual(registry.registry_entries.attributes[0].display_name,
+                         registry2.registry_entries.attributes[0].display_name)
+        self.assertEqual(registry.registry_entries.attributes[0].read_only,
+                         registry2.registry_entries.attributes[0].read_only)
+        self.assertEqual(registry.registry_entries.attributes[0].
+                         attribute_type,
+                         registry2.registry_entries.attributes[0].
+                         attribute_type)
